﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Sockets;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

namespace WebService
{
    class Server
    {
        
        private static IPAddress ip = Dns.GetHostEntry("localhost").AddressList[1];
        private static int port = 8888;
        public static string ROOT = Path.GetFullPath(Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments) + "/WebServer");
        public static string defaultFile = "\\index.html";
        private static TcpListener listener = null;
        private static List<Handler> handles = new List<Handler>();
        public static Dictionary<string, byte[]> cache = new Dictionary<string, byte[]>();

        public static void start()
        {
            Program.active = true;

            initialize();

            listener = generate();
            if (listener != null)
            {
                Console.WriteLine("Waiting for connection on... " + ip +":"+ port);
                while (Program.active)
                {
                    handles.Add(new Handler(listener.AcceptTcpClient()));
                    handles.RemoveAll(x => x.complete);
                    Thread.Sleep(1);
                }
            }
        }
        public static void stop()
        {
            Program.active = false;
            listener = null;
        }

        public static TcpListener generate()
        {
            TcpListener tcp = null;
            try
            {
                tcp = new TcpListener(ip, port);
                tcp.Start();
                return tcp;
            }
            catch (Exception e)
            {
                Console.WriteLine(e.ToString());
            }
            return null;
        }

        private static void initialize()
        {
            if (!Directory.Exists(ROOT))
            {
                Directory.CreateDirectory(ROOT);
                WebClient client = new WebClient();
                client.DownloadFile("http://designwoop.com/uploads/2012/11/9-580x326.jpg", Path.GetFullPath(ROOT + "\\default.jpg"));

                List<string> html = new List<string>();
                html.Add("<!DOCTYPE html>");
                html.Add("<html>");
                html.Add("<head>");
                html.Add("<title>WebServer</title>");
                html.Add("<style>");
                html.Add("body, html { font-family: Tahoma, Geneva, sans-serif; position: absolute; border: none; margin: 0; padding: 0; width: 100%; height: 100%; overflow: hidden; }");
                html.Add("table, tr, td { height: 100%; width: 100%; border: none; border-collapse: collapse; }");
                html.Add("td { vertical-align: middle; background-image: url('default.jpg'); background-attachment: fixed; background-size: cover; }");
                html.Add("div { text-align: center; width: 100%; padding-top: 5%; padding-bottom: 5%; background-color: rgba(0,0,0,.6); }");
                html.Add("div h1 { color: white; }");
                html.Add("div h3, h4, h5 { color: silver; margin: 0; padding: 2px;}");
                html.Add("</style>");
                html.Add("</head>");
                html.Add("<body>");
                html.Add("<style>");
                html.Add("</style>");
                html.Add("<table>");
                html.Add("<tbody>");
                html.Add("<tr>");
                html.Add("<td>");
                html.Add("<div>");
                html.Add("<h1>Welcome to the WebServer</h1>");
                html.Add("<h3>Developed by Team 8</h3>");
                html.Add("<h5>Jeremy Ingraham</h5>");
                html.Add("<h5>Thomas Adams</h5>");
                html.Add("<h5>Chris Ballard</h5>");
                html.Add("<h5>Eleanor Wyatt</h5>");
                html.Add("<h5>Sami Elarab</h5>");
                html.Add("<h5>Jose Canales</h5>");
                html.Add("</div>");
                html.Add("</td>");
                html.Add("</tr>");
                html.Add("</tbody>");
                html.Add("</table>");
                html.Add("</body>");
                html.Add("</html>");
                File.WriteAllLines(Path.GetFullPath(ROOT + defaultFile), html.ToArray());
            }
        }
    }
}
